package com.fjhx.tenant.service.dict.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fjhx.tenant.entity.dict.dto.DictCommonDataDto;
import com.fjhx.tenant.entity.dict.dto.DictCommonDataSelectDto;
import com.fjhx.tenant.entity.dict.po.DictCommonData;
import com.fjhx.tenant.entity.dict.po.DictTenantData;
import com.fjhx.tenant.entity.dict.vo.DictCommonDataVo;
import com.fjhx.tenant.mapper.dict.DictCommonDataMapper;
import com.fjhx.tenant.service.dict.DictCommonDataService;
import com.fjhx.tenant.service.dict.DictTenantDataService;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.wrapper.IWrapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Objects;


/**
 * <p>
 * 业务字典明细 服务实现类
 * </p>
 *
 * @author
 * @since 2023-03-30
 */
@Service
public class DictCommonDataServiceImpl extends ServiceImpl<DictCommonDataMapper, DictCommonData> implements DictCommonDataService {

    @Autowired
    private DictTenantDataService dictTenantDataService;

    @Override
    public Page<DictCommonDataVo> getPage(DictCommonDataSelectDto dto) {
        IWrapper<DictCommonData> wrapper = getWrapper();
        wrapper.eq("dcd", DictCommonData::getDictCode, dto.getDictCode());
        wrapper.orderByAsc("dcd", DictCommonData::getSort);
        return this.baseMapper.getPage(dto.getPage(), wrapper);
    }

    @Override
    public DictCommonDataVo detail(Long id) {
        DictCommonData DictCommonData = this.getById(id);
        DictCommonDataVo result = BeanUtil.toBean(DictCommonData, DictCommonDataVo.class);
        return result;
    }

    @Override
    public void add(DictCommonDataDto dictCommonDataDto) {

        dictTenantDataService.nameDuplication(DictTenantData::getDictKey, dictCommonDataDto.getDictKey(), "key已存在");
        dictTenantDataService.nameDuplication(DictTenantData::getDictValue, dictCommonDataDto.getDictValue(), "value已存在");

        nameDuplication(DictCommonData::getDictKey, dictCommonDataDto.getDictKey(), "key已存在");
        nameDuplication(DictCommonData::getDictValue, dictCommonDataDto.getDictValue(), "value已存在");

        this.save(dictCommonDataDto);
    }

    @Override
    public void edit(DictCommonDataDto dictCommonDataDto) {
        dictCommonDataDto.setDictCode(null);

        Long id = dictCommonDataDto.getId();
        if (Objects.isNull(id)) {
            throw new ServiceException("id不能为空");
        }

        dictTenantDataService.nameDuplication(DictTenantData::getDictKey, dictCommonDataDto.getDictKey(), id, "key已存在");
        dictTenantDataService.nameDuplication(DictTenantData::getDictValue, dictCommonDataDto.getDictValue(), id, "value已存在");

        nameDuplication(DictCommonData::getDictKey, dictCommonDataDto.getDictKey(), id, "key已存在");
        nameDuplication(DictCommonData::getDictValue, dictCommonDataDto.getDictValue(), id, "value已存在");

        this.updateById(dictCommonDataDto);
    }

    @Override
    public void delete(Long id) {
        this.removeById(id);
    }

}
